ApiKeyAuth class

An API key authentication scheme.

Inheritance
Annotations
  • @immutable

Constructors

ApiKeyAuth({required String name, required ApiKeyLocation sendIn, required String secretName})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The key name used when sending the API key.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretName → String
The name of the secret.
finalinherited
sendIn → ApiKeyLocation
Where to send the API key.
final

Methods

haveSecrets(String? getSecret(String name)) → bool
Used to check if the getSecret function has all the secrets for this auth.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(String? getSecret(String name)) → ResolvedAuth
Used to resolve the auth using the getSecret function.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited