HttpAuth class

An HTTP authentication scheme.

Inheritance
Annotations
  • @immutable

Constructors

HttpAuth({required String scheme, required String secretName})
Create a new HTTP authentication scheme.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → String
The scheme to use when sending the HTTP token.
final
secretName → String
The name of the secret.
finalinherited

Methods

haveSecrets(String? getSecret(String name)) → bool
Used to check if the getSecret function has all the secrets for this auth.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(String? getSecret(String name)) → ResolvedAuth
Used to resolve the auth using the getSecret function.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited