MissingSecretsException class

An exception thrown when a required secret is missing.

Implemented types

Constructors

MissingSecretsException(AuthRequest auth, [String message = 'Missing required secrets for auth'])
Create a new MissingSecretsException.
const

Properties

auth → AuthRequest
The auth request that is missing secrets.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
The message of the exception.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited