NoAuth class

An auth request that does nothing.

Inheritance
Annotations
  • @immutable

Constructors

NoAuth()
Create a new NoAuth.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

haveSecrets(String? getSecret(String name)) → bool
Always returns true since no auth is required.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(String? getSecret(String name)) → ResolvedAuth
Returns a ResolvedAuth with no headers or parameters.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited