SecretAuth class abstract

An auth request that requires a secret.

Inheritance
Implementers
Annotations
  • @immutable

Constructors

SecretAuth({required String secretName})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretName → String
The name of the secret.
final

Methods

haveSecrets(String? getSecret(String name)) → bool
Used to check if the getSecret function has all the secrets for this auth.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(String? getSecret(String name)) → ResolvedAuth
Used to resolve the auth using the getSecret function.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited