ApiClient class
The client interface for the API. Subclasses can override invokeApi to add custom behavior.
Constructors
Properties
- baseUri → Uri
-
final
- client → Client
-
final
-
defaultHeaders
→ Map<
String, String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- readSecret → String? Function(String name)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
invokeApi(
{required Method method, required String path, Map< String, List< queryParameters = const {}, Object? body, BodyContentType bodyContentType = BodyContentType.json, Map<String> >String, String> headerParameters = const {}, AuthRequest? authRequest}) → Future<Response> -
invokeApiMultipart(
{required Method method, required String path, required Map< String, String> fields, required List<MultipartFile> files, Map<String, List< queryParameters = const {}, Map<String> >String, String> headerParameters = const {}, AuthRequest? authRequest}) → Future<Response> -
Send a
multipart/form-datarequest built fromfields(text parts) andfiles(file parts). TheContent-Typeheader is set byMultipartRequestitself, including the generated boundary — do not pass one viaheaderParameters. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveAuth(
AuthRequest? authRequest) → ResolvedAuth - Resolve an AuthRequest into a ResolvedAuth. Override this to add custom auth handling.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited